import { describe, expect, it } from "vitest";
import { getBuild } from "./utils";
import { getClassName } from "../index";

describe("babel-tailwind", () => {
  const compileESBuild = getBuild("styleObject");

  it("supports conversion into CSSProperties", async () => {
    const { files } = await compileESBuild({
      clsx: "emotion",
      expectFiles: 1,
      javascript: `
        import { tws } from "@aet/tailwind/macro";

        export function Hello() {
          return (
            <div style={tws\`p-2 text-center hover:font-semibold sm:p-1\`}>
              Hello, world!
            </div>
          );
        }
    `,
    });

    const clsName = getClassName("p-2 text-center hover:font-semibold sm:p-1").replace(
      /^tw-/,
      "tw_"
    );
    expect(files.js.text).toContain(
      [
        `var ${clsName} = {`,
        '  padding: "0.5rem",',
        '  textAlign: "center",',
        '  "&:hover": {',
        '    fontWeight: "600"',
        "  },",
        '  "@media (min-width: 640px)": {',
        '    padding: "0.25rem"',
        "  }",
        "}",
      ].join("\n")
    );
    expect(files.js.text).toContain(`style: ${clsName}`);
  });

  it("supports .hover, .focus, .active, .group-hover, .group-focus, .group-active", async () => {
    const { files } = await compileESBuild({
      clsx: "emotion",
      expectFiles: 1,
      javascript: `
        import { tws } from "@aet/tailwind/macro";

        export const style = [
          tws.hover\`font-semibold\`,
          tws.focus\`font-bold\`,
          tws.active\`font-light\`,
          tws.hover.active\`p-2\`,
        ];
    `,
    });

    const semibold = getClassName("hover:font-semibold").replace(/^tw-/, "tw_");
    const bold = getClassName("focus:font-bold").replace(/^tw-/, "tw_");
    const light = getClassName("active:font-light").replace(/^tw-/, "tw_");
    const p = getClassName("active:hover:p-2").replace(/^tw-/, "tw_");

    expect(files.js.text).toContain(
      [
        `var ${bold} = {`,
        '  "&:focus": {',
        '    fontWeight: "700"',
        "  }",
        "};",
        `var ${light} = {`,
        '  "&:active": {',
        '    fontWeight: "300"',
        "  }",
        "};",
        `var ${p} = {`,
        '  "&:hover:active": {',
        '    padding: "0.5rem"',
        "  }",
        "};",
        `var ${semibold} = {`,
        '  "&:hover": {',
        '    fontWeight: "600"',
        "  }",
        "};",
      ].join("\n")
    );
  });
});
